/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.crop;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.Genus;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;

/**
 * Add a new Genus to the active crop in the croplist.
 * 
 * @author Gerben Feenstra & Merijn Zengers
 */
@NbBundle.Messages({ 
    "Add genus action name=Add genus",
    "Add genus action tooltip=Add genus",
    "Genus default name=User created genus"
})
public class AddGenusAction extends AbstractAction {
   
    private static final String ADD_GENUS_ACTION_TOOLTIP = Bundle.Add_genus_action_tooltip();
    private static final String ADD_GENUS_ICON = "nl/cloudfarming/client/stock/crop/genus.png";
    private static final String ADD_GENUS_ENABLED = "nl/cloudfarming/client/stock/crop/genus.png";
    private static final String ADD_GENUS_DISABLED = "nl/cloudfarming/client/stock/crop/genus.png";
                    
    /**
     * Makes this action for a specific node
     * @param cropDefinitionNode 
     */
    public AddGenusAction() {
        super(Bundle.Add_genus_action_name());
        this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_GENUS_ICON));
        this.putValue(Action.SHORT_DESCRIPTION, ADD_GENUS_ACTION_TOOLTIP);
    }
        
    @Override
    public void setEnabled(boolean doEnable) {
        if(doEnable){
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_GENUS_ENABLED));
        }
        else{
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(ADD_GENUS_DISABLED));
        }
        super.setEnabled(doEnable);
    }
        
    @Override
    public void actionPerformed(ActionEvent e) {
        // Find active crop
        GeneraAggregateNode node = Utilities.actionsGlobalContext().lookup(GeneraAggregateNode.class);
        CropDefinition activeCropDefinition = node.getParentNode().getLookup().lookup(CropDefinition.class);
        assert activeCropDefinition != null : "Tried to add genus, but parent cropdefinition cannot be found in lookup";  
        
        // Create new genus for the active crop
        Genus genus = new Genus(Bundle.Genus_default_name(), Bundle.Variety_default_source());
        CropStorage.getInstance().addGenus(activeCropDefinition, genus);
    }
}
