/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.crop;

import java.util.logging.Logger;
import javax.swing.JToolBar;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.Genus;
import nl.cloudfarming.client.crop.model.Variety;
import org.openide.util.Lookup;
import org.openide.util.LookupEvent;
import org.openide.util.LookupListener;
import org.openide.util.Utilities;

/**
 * Toolbar to store all actions possible inside the croplist.
 * Registers itself as lookuplistener of cropdefinition, genus and variety.
 * 
 * @author Gerben Feenstra & Merijn Zengers
 */

public class CropListToolBar extends JToolBar {

    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.stock.crop.CropListToolBar");
    private final Listener lookupListener = new Listener();
    
    // Lookup results
    private final Lookup.Result<CropDefinition> cropDefLookupResult;
    private final Lookup.Result<Genus> genusLookupResult;
    private final Lookup.Result<Variety> varietyLookupResult;
    
    // Actions
    private RemoveAction removeAction;
    private AddCropAction addCropAction;
    private AddGenusAction addGenusAction;
    private AddVarietyAction addVarietyAction;

    /**
     * Constructs  toolbar, adds actions to it
     */
    public CropListToolBar() {
        // Create remove action, disable by default
        removeAction = new RemoveAction();
        removeAction.setEnabled(false);
        
        // Create Add cropdefinition action, enabled by default
        addCropAction = new AddCropAction();
        addCropAction.setEnabled(true); // Always enabled.

        // Create Add Genus action, Disable by default
        addGenusAction = new AddGenusAction();
        addGenusAction.setEnabled(false); 
        
        // Create Add Genus action, Disable by default
        addVarietyAction = new AddVarietyAction();
        addVarietyAction.setEnabled(false); 
        
        // Add action(s) to this toolbar
        this.add(removeAction);
        this.add(addCropAction);
        //this.add(addGenusAction);
        //this.add(addVarietyAction);

        // Register CropDefinitionNode.class to listen to
        cropDefLookupResult = Utilities.actionsGlobalContext().lookupResult(CropDefinition.class);
        cropDefLookupResult.addLookupListener(lookupListener); 
        
        // Register Genus.class to listen to
        genusLookupResult = Utilities.actionsGlobalContext().lookupResult(Genus.class);
        genusLookupResult.addLookupListener(lookupListener);     
               
        // Register Variety.class to listen to
        varietyLookupResult = Utilities.actionsGlobalContext().lookupResult(Variety.class);
        varietyLookupResult.addLookupListener(lookupListener);
    }

    /**
     * Listens to lookup changes if CropDefinition, genus or variety are in the lookup it will enable the suitable actions
     */
    private class Listener implements LookupListener {
        @Override
        public void resultChanged(LookupEvent ev) {
            // Disabled by default
            removeAction.setEnabled(false);
            addGenusAction.setEnabled(false);
            addVarietyAction.setEnabled(false);
            
            Lookup.Result<Object> r = (Lookup.Result<Object>) ev.getSource();
            for (Object o : r.allInstances()) {
                if(o instanceof CropDefinition || o instanceof Genus || o instanceof Variety){
                    removeAction.setEnabled(true);
                    break;
                }  
            }
        }
    }
}