/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.crop;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import javax.swing.GroupLayout;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JToolBar;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.crop.model.CropDefinition;
import org.openide.explorer.ExplorerManager;
import org.openide.explorer.view.TreeTableView;
import org.openide.nodes.Node;
import org.openide.nodes.PropertySupport;
import org.openide.util.Exceptions;

/**
 * Visual component to display a treetableview of the croplist with a toolbar on top.
 * Uses explorermanager to get the rootnode.
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class CropListVisualPanel extends JPanel implements ExplorerManager.Provider{

    private ExplorerManager explorerManager;
    private TreeTableView cropListTreeView;
    private JToolBar croplistToolbar; 
    JScrollPane scrollPane; 
    
    /**
     * Creates new CropListVisualPanel
     */
    public CropListVisualPanel(ExplorerManager explorerManager) {
        this.explorerManager = explorerManager;
        this.setLayout(new BorderLayout());//new MigLayout("wrap"));
        
        // Create treeview
        cropListTreeView = new TreeTableView();
        
        // Create toolbar
        croplistToolbar = new CropListToolBar();
        croplistToolbar.setFloatable(false);
        
        // Create scrollpane
        scrollPane = new JScrollPane();
        scrollPane.setColumnHeaderView(croplistToolbar);     
        scrollPane.setViewportView(cropListTreeView);

        this.add(scrollPane);
        
        try {
            Node.Property name = new PropertySupport.Reflection(new CropDefinition(""), String.class, "name");
            Node.Property source = new PropertySupport.Reflection(new CropDefinition(""), String.class, "getSource",null);
            Node.Property color = new PropertySupport.Reflection(new CropDefinition(""), Color.class, "getDefaultColor",null);
            cropListTreeView.setProperties(new Node.Property[]{name,source, color});
            cropListTreeView.setRootVisible(false);           
        } catch (NoSuchMethodException ex) {
            Exceptions.printStackTrace(ex);
        }
    }

    @Override
    public ExplorerManager getExplorerManager() {
        return explorerManager;
    }
}
