/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.crop;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.util.Exceptions;

/**
 * Manages storing and loading of the cropstorage
 * @author Timon Veenstra <monezz@gmail.com>
 */
class CropStorageManager {
    
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.farm.fieldplan.CropFieldManagerImpl");
    private static final String CROPS_STORAGE_FILE = "data";
       
    static void save(CropStorage cropStorage, FileObject cropsFolder)throws IOException{
        LOGGER.log(Level.FINEST, "saving cropStorage data to folder {0}", cropsFolder.getName());
        try (ObjectOutputStream oos = new ObjectOutputStream(cropsFolder.createData(CROPS_STORAGE_FILE).getOutputStream())) {
            oos.writeObject(cropStorage);
        }        
    }
    
    static void load(FileObject cropsFolder) throws IOException{
        LOGGER.log(Level.FINEST, "loading CropStorage data from  {0}", cropsFolder.getName());
        FileObject cropStorageFile = cropsFolder.getFileObject(CROPS_STORAGE_FILE);
        
        if (cropStorageFile == null){
            LOGGER.log(Level.FINEST, "crop storage did not exist yet, returning new one.");      
            return;
        }
        
        try (ObjectInputStream ois = new ObjectInputStream(cropStorageFile.getInputStream())) {
            ois.readObject();
        } catch (ClassNotFoundException | IOException ex) {
            Exceptions.printStackTrace(ex);
            throw new DataObjectNotFoundException(cropStorageFile);
        }
    }
}
