/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.crop;

import java.beans.IntrospectionException;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.List;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.CropBean;
import nl.cloudfarming.client.crop.model.Genus;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 * Aggregate node under a cropdefinitionnode to group genera of this cropdefinitionnode together
 * @author Gerben Feenstra
 */
@NbBundle.Messages("GeneraNode.name=Genera")
public class GeneraAggregateNode extends AbstractNode {
    
    private static final String GENUS_AGGREGATE_ICON = "nl/cloudfarming/client/stock/crop/genus_aggregate.png";
        
    public GeneraAggregateNode(List<Genus> genera, Lookup lookup) {
        super(Children.create(new GeneraChildFactory(genera, lookup), true));
        setName(Bundle.GeneraNode_name());
        this.setIconBaseWithExtension(GENUS_AGGREGATE_ICON);
    }
    
    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.stock.crop.genus");
    }
    
    @Override
    public Action[] getActions(boolean context) {
        Action[] actions = new Action[1];
        actions[0] = new AddGenusAction();
        return actions;
    }
}

/**
 * Create individual genus nodes 
 * @author Gerben Feenstra
 */
class GeneraChildFactory extends ChildFactory<Genus> implements PropertyChangeListener {

    private final List<Genus> genera;
    private Lookup lookup;

    public GeneraChildFactory(List<Genus> genera, Lookup lookup) {
        this.genera = genera;
        this.lookup = lookup;
        CropStorage.getInstance().addPropertyChangeListener(CropStorage.PROP_GENUS, this);
        for(Genus genus : genera){
            genus.addPropertyChangeListener(CropBean.PROP_NAME, this);
        }
    }

    @Override
    protected boolean createKeys(List<Genus> toPopulate) {
        toPopulate.addAll(this.genera);
        return true;
    }

    @Override
    protected Node createNodeForKey(Genus key) {
        try {
            return new GenusNode(key, lookup);
        } catch (IntrospectionException ex) {
            Exceptions.printStackTrace(ex);
            return null;
        }
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        this.refresh(true);
    }
}