/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.stock.crop;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import nl.cloudfarming.client.crop.model.CropDefinition;
import nl.cloudfarming.client.crop.model.Genus;
import nl.cloudfarming.client.crop.model.Variety;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;

/**
 * Removes selected items in the croplist. 
 * Supports Crops, genera and varieties
 * For genera and varieties the parent cropdefinition must also be in the lookup.
 * 
 * @author Gerben Feenstra & Merijn Zengers
 */
@NbBundle.Messages({
    "Remove_action_name=Remove", 
    "toolbar_remove_action_tooltip=Remove"
})
public class RemoveAction extends AbstractAction {
    
    private static final String REMOVE_ACTION_TOOLTIP = Bundle.toolbar_remove_action_tooltip();
    private String REMOVE_ICON_ENABLED = "nl/cloudfarming/client/stock/crop/enabled_cross.png";
    private String REMOVE_ICON_DISABLED = "nl/cloudfarming/client/stock/crop/disabled_cross.png";
    
    /**
     * Makes this action for a specific node
     * @param cropDefinitionNode 
     */
    public RemoveAction() {
        super(Bundle.Remove_action_name());
        this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(REMOVE_ICON_DISABLED));
        this.putValue(Action.SHORT_DESCRIPTION, REMOVE_ACTION_TOOLTIP);
    }

    @Override
    public void setEnabled(boolean doEnable) {
        if(doEnable){
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(REMOVE_ICON_ENABLED));
        }
        else{
            this.putValue(Action.SMALL_ICON, ImageUtilities.loadImage(REMOVE_ICON_DISABLED));
        }
        super.setEnabled(doEnable);
    }
        
    @Override
    public void actionPerformed(ActionEvent e) {
        CropDefinition activeCropDefinition = Utilities.actionsGlobalContext().lookup(CropDefinition.class);
        Genus genus = Utilities.actionsGlobalContext().lookup(Genus.class);
        Variety variety = Utilities.actionsGlobalContext().lookup(Variety.class);
        
        if(genus != null){
            assert activeCropDefinition != null : "Tried to remove genus, but parent cropdefinition cannot be found in lookup";
            CropStorage.getInstance().removeGenus(activeCropDefinition, genus);
        } else if(variety != null){
            assert activeCropDefinition != null : "Tried to remove genus, but parent cropdefinition cannot be found in lookup";
            CropStorage.getInstance().removeVariety(activeCropDefinition, variety);
        } else{
             assert activeCropDefinition != null : "Tried to remove cropDefinition, but cannot be found in lookup";
             CropStorage.getInstance().removeCropDefinition(activeCropDefinition);
        } 
    }
}
